==> haskell-http-api-data-0.3.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.3.3
id: http-api-data-0.3.3-8AdTBIOisZBIby08WtvS1h
key: http-api-data-0.3.3-8AdTBIOisZBIby08WtvS1h
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
exposed-modules:
    Web.HttpApiData Web.FormUrlEncoded Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
abi: e1bb88b62fe7250279aeec2b498812ec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/http-api-data-0.3.3
hs-libraries: HShttp-api-data-0.3.3-8AdTBIOisZBIby08WtvS1h
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    uri-bytestring-0.2.2.1-JIWekMkFWvlIexLYbfEa2p
    uuid-types-1.0.3-B0MHhveK6nAFg4yUFzGa9G
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.3.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.3.3
id: http-api-data-0.3.3-KvaBaugJKVJ9zNy4Ai3IWV
key: http-api-data-0.3.3-KvaBaugJKVJ9zNy4Ai3IWV
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
exposed-modules:
    Web.HttpApiData Web.FormUrlEncoded Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
abi: e2853305f82fcaf7275fd8c4fb989051
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-api-data-0.3.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/http-api-data-0.3.3
hs-libraries: HShttp-api-data-0.3.3-KvaBaugJKVJ9zNy4Ai3IWV
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    uri-bytestring-0.2.2.1-4MWCrcuKPOLGGV9OONOpVH
    uuid-types-1.0.3-6vhVYNvy9CXBhrOtLejPEC
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
